`anhima` - Exploration and analysis of genetic variation data
=============================================================

* Documentation: http://anhima.readthedocs.org
* Examples: http://nbviewer.ipython.org/github/alimanfoo/anhima/tree/master/examples/
* Source: http://github.com/alimanfoo/anhima
* Mailing list: https://groups.google.com/forum/#!forum/anhima
* Release notes: https://github.com/alimanfoo/anhima/releases

See also [information for developers](https://github.com/alimanfoo/anhima/blob/master/DEVELOP.md).